(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     66214,       2081]
NotebookOptionsPosition[     59767,       1851]
NotebookOutlinePosition[     60126,       1867]
CellTagsIndexPosition[     60083,       1864]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["code", "Chapter",
 CellChangeTimes->{{3.667296655402238*^9, 3.667296655897064*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.667296640163199*^9, 3.6672966454798183`*^9}}],

Cell[CellGroupData[{

Cell["PolarizationOperator", "Subchapter",
 CellChangeTimes->{{3.667296662433476*^9, 3.667296664199643*^9}, 
   3.667296843481374*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "::", "usage"}], "=", 
   "\"\<PolarizationOperator[j] is an operator for the polarization level of \
spin j in a multispin system. \
OperatorAmplitude[\[Rho]\[Rule]PolarizationOperator[j]] returns 1 if the \
density operator \[Rho] represents an ensemble with fully-polarized spins j.  \
PolarizationOperator[{j,k..}] is the operator for the mean polarization over \
the specified set of spins. PolarizationOperator[] or \
PolarizationOperator[All] generates the operator for the mean polarization of \
all spins.\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.66729666829174*^9, 3.667296837921706*^9}, {
  3.667297248558276*^9, 3.667297275129602*^9}, {3.6672973091740627`*^9, 
  3.667297318847485*^9}, {3.667299764681471*^9, 3.667299800950261*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", "args___", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{"SpinSystem", "::", "notready"}], "]"}], ";", 
      RowBox[{"Abort", "[", "]"}]}], ")"}], "/;", 
    RowBox[{"TrueQ", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"SpinSystem", "/.", 
        RowBox[{"Options", "[", "SpinSystem", "]"}]}], ")"}], "\[Equal]", 
      "Undefined"}], "]"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 InitializationGroup->True,
 CellChangeTimes->{{3.439554471001298*^9, 3.439554471718799*^9}, 
   3.448355874989354*^9, 3.456164514297298*^9, {3.5470264333152847`*^9, 
   3.547026434660329*^9}, 3.6672969599302263`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", "]"}], ":=", 
   RowBox[{"PolarizationOperator", "[", "All", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.667297287123048*^9, 3.667297301770344*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", "spins_", "]"}], ":=", 
   RowBox[{"PolarizationOperator", "[", 
    RowBox[{"spins", ",", " ", 
     RowBox[{"SpinSystem", "[", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.667296859218829*^9, 3.667296874653122*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", 
    RowBox[{"All", ",", "spinsys_"}], "]"}], ":=", 
   RowBox[{"PolarizationOperator", "[", 
    RowBox[{
     RowBox[{"First", "/@", "spinsys"}], ",", "spinsys"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.667297327982827*^9, 3.667297343642228*^9}, {
  3.667299317014785*^9, 3.6672993355204372`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", 
    RowBox[{"spins_List", ",", "spinsys_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"FreeQ", "[", 
         RowBox[{"#", ",", "$Failed"}], "]"}], ",", "#", ",", "$Failed"}], 
       "]"}], "&"}], "@", "\[IndentingNewLine]", "Plus"}], "@@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PolarizationOperator", "[", 
        RowBox[{"#", ",", "spinsys"}], "]"}], "&"}], "/@", "spins"}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6672968466188993`*^9, 3.667296914365736*^9}, {
   3.6672983279243603`*^9, 3.667298345744331*^9}, 3.66729870702059*^9, {
   3.667299386743327*^9, 3.667299433048047*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PolarizationOperator", "[", 
     RowBox[{
      RowBox[{"j", ":", 
       RowBox[{"Except", "[", "_List", "]"}]}], ",", "spinsys_"}], "]"}], "/;", 
    RowBox[{"!", 
     RowBox[{"ValidSpinQ", "[", 
      RowBox[{"j", ",", "spinsys"}], "]"}]}]}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Message", "[", 
      RowBox[{
       RowBox[{"SpinSystem", "::", "invspin"}], ",", "j"}], "]"}], ";", 
     "$Failed"}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.667297024403761*^9, 3.6672970659716463`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationOperator", "[", 
    RowBox[{
     RowBox[{"j", ":", 
      RowBox[{"Except", "[", "_List", "]"}]}], ",", "spinsys_"}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"PolarizationOperator", "[", 
      RowBox[{"j", ",", "spinsys"}], "]"}], "=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Ij", ",", "dim"}], "}"}], ",", 
       RowBox[{"(", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Ij", "=", 
          RowBox[{"SpinQuantumNumber", "[", 
           RowBox[{"j", ",", "spinsys"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"dim", "=", 
          RowBox[{"BasisDimension", "[", 
           RowBox[{"ZeemanBasis", "[", "spinsys", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Ij", "+", "1"}], ")"}], "*", "dim"}], ")"}]}], ")"}], 
          "*", 
          RowBox[{"opI", "[", 
           RowBox[{"j", ",", "\"\<z\>\""}], "]"}]}]}], "\[IndentingNewLine]", 
        ")"}]}], "]"}]}], "\[IndentingNewLine]", ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6672970774795647`*^9, 3.6672971396124763`*^9}, 
   3.6672976862977047`*^9, {3.667297728979753*^9, 3.667297740904056*^9}, {
   3.6672978982976513`*^9, 3.667297947559244*^9}, {3.66729893710867*^9, 
   3.667299008130795*^9}, {3.66729913234339*^9, 3.667299172314522*^9}, {
   3.6672992208049*^9, 3.6672992368230257`*^9}, {3.667299575398924*^9, 
   3.667299593995556*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["tests", "Chapter",
 CellChangeTimes->{{3.667296655402238*^9, 3.667296655897064*^9}, {
  3.6672971480056057`*^9, 3.667297148544764*^9}}],

Cell[CellGroupData[{

Cell["single spin-1/2", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.667297369213513*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\"}\\\"}]\\)\
\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, {3.667297749528201*^9, 3.667297773839204*^9}, 
   3.6672979546301537`*^9, 3.667298352452676*^9, 3.66729871473029*^9, 
   3.6672990189354753`*^9, 3.667299183110629*^9, 3.6672992555625467`*^9, 
   3.667299441534411*^9, 3.667299607781598*^9, {3.667299829960732*^9, 
   3.667299841278141*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.66729984130448*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Alpha]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, {
   3.667297749696903*^9, 3.667297774008054*^9}, 3.667297954666252*^9, 
   3.667298352605461*^9, 3.667298714890348*^9, 3.667299019104512*^9, 
   3.66729918329475*^9, 3.667299255718813*^9, 3.667299441700795*^9, 
   3.667299607944516*^9, 3.6672998413331947`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, {
   3.667297749715893*^9, 3.66729777402629*^9}, 3.667297954684108*^9, 
   3.667298352642474*^9, 3.667298714909481*^9, 3.66729901912304*^9, 
   3.6672991833150883`*^9, 3.66729925573672*^9, 3.667299441716848*^9, 
   3.667299607960812*^9, 3.667299841352165*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, {3.6672977497440453`*^9, 3.667297774057893*^9}, 
   3.6672979547133102`*^9, 3.667298352675406*^9, 3.6672987149376907`*^9, 
   3.667299019150257*^9, 3.667299183341898*^9, 3.667299255765821*^9, 
   3.667299441747285*^9, 3.6672996079911423`*^9, 3.667299841383008*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["two spins-1/2", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.6672973784273167`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}, 
   3.6672973814328327`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6672971536086473`*^9, 3.6672973818690767`*^9, 
  3.667297611339739*^9, 3.667297753177017*^9, 3.667297960638413*^9, 
  3.66729804410541*^9, 3.667298356989984*^9, 3.667298718198656*^9, 
  3.667299023075719*^9, 3.667299187330536*^9, 3.667299255896969*^9, 
  3.667299445003078*^9, 3.667299855234445*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \
\\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.6672971536086473`*^9, 3.6672973818690767`*^9, 
  3.667297611339739*^9, 3.667297753177017*^9, 3.667297960638413*^9, 
  3.66729804410541*^9, 3.667298356989984*^9, 3.667298718198656*^9, 
  3.667299023075719*^9, 3.667299187330536*^9, 3.667299255896969*^9, 
  3.667299445003078*^9, 3.667299855363158*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm], "2"]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "]"}]], "Input",
 CellChangeTimes->{3.667299877125979*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm], "2"], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm], "2"]}]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299877752056*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Alpha]\[Alpha]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
  3.667297385368788*^9, 3.66729738572875*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, 3.66729775338386*^9, 3.667297960859028*^9, 
   3.667298044308056*^9, 3.66729835720177*^9, 3.667298718382856*^9, 
   3.667299023264474*^9, 3.667299187548533*^9, 3.667299256058188*^9, 
   3.667299445194763*^9, 3.667299855399437*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, {
  3.667297405416499*^9, 3.667297405686414*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.6672974062368383`*^9, 3.6672977534026623`*^9, 3.667297960891883*^9, 
   3.667298044338065*^9, 3.667298357220763*^9, 3.667298718411007*^9, 
   3.667299023292684*^9, 3.6672991875820312`*^9, 3.6672992560823107`*^9, 
   3.667299445221216*^9, 3.66729985542146*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, {
   3.667297405416499*^9, 3.667297405686414*^9}, 3.6672979769550858`*^9}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.6672974062368383`*^9, 3.6672977534026623`*^9, {3.667297960891883*^9, 
   3.667297977338642*^9}, 3.6672980443581944`*^9, 3.667298357250917*^9, 
   3.667298718430285*^9, 3.667299023311453*^9, 3.6672991876160707`*^9, 
   3.667299256101636*^9, 3.667299445242248*^9, 3.6672998554606133`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, 3.667297753434641*^9, 
   3.66729796091255*^9, 3.6672980443881397`*^9, 3.6672983572699738`*^9, 
   3.667298718460392*^9, 3.667299023342141*^9, 3.6672991876500597`*^9, 
   3.667299256134572*^9, 3.667299445271484*^9, 3.667299855494727*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Alpha]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.6672987282382193`*^9, 3.667298728507353*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, 3.667297753434641*^9, 
   3.66729796091255*^9, 3.6672980443881397`*^9, 3.6672983572699738`*^9, {
   3.667298718460392*^9, 3.667298729217765*^9}, 3.667299023362208*^9, 
   3.6672991876821737`*^9, 3.6672992561543837`*^9, 3.667299445292235*^9, 
   3.6672998555273657`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Alpha]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.6672987282382193`*^9, 3.667298728507353*^9}, 3.6672994539177837`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SpinSystem", "::", "invspin"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"spin index \[NoBreak]\\!\\(\\*RowBox[{\\\"3\\\"}]\\)\
\[NoBreak] is not in current spin system. Use SetSpinSystem or SetBasis to \
set up spin system.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.667299454486023*^9, 3.667299855665872*^9}],

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"\<\"\[LeftBracketingBar]\[Alpha]\[Beta]\[RightAngleBracket]\"\>", 
    ".", "\<\"<\[Alpha]\[Beta]|\"\>"}], "\[Rule]", "$Failed"}], 
  "]"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, 3.667297753434641*^9, 
   3.66729796091255*^9, 3.6672980443881397`*^9, 3.6672983572699738`*^9, {
   3.667298718460392*^9, 3.667298729217765*^9}, 3.667299023362208*^9, 
   3.6672991876821737`*^9, 3.6672992561543837`*^9, {3.667299445292235*^9, 
   3.667299454491034*^9}, 3.6672998556733713`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3 spins-1/2", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.6672973784273167`*^9}, 
   3.667297457561099*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}, 
   3.6672973814328327`*^9, 3.667297459922954*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6672971536086473`*^9, 3.6672973818690767`*^9, 
  3.667297463046542*^9, 3.6672980100718927`*^9, 3.6672986710230703`*^9, 
  3.667298736850156*^9, 3.66729902773462*^9, 3.6672991924759483`*^9, 
  3.6672992562835083`*^9, 3.6672994659796762`*^9, 3.667299903947866*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6672971536086473`*^9, 3.6672973818690767`*^9, 
  3.667297463046542*^9, 3.6672980100718927`*^9, 3.6672986710230703`*^9, 
  3.667298736850156*^9, 3.66729902773462*^9, 3.6672991924759483`*^9, 
  3.6672992562835083`*^9, 3.6672994659796762`*^9, 3.667299904078876*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm], "4"]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, 
   3.667299904110488*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Alpha]\[Alpha]\[Alpha]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
  3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
  3.6672974719718246`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, 3.667298737016548*^9, 
   3.6672990279181013`*^9, 3.667299192646027*^9, 3.6672992564286118`*^9, 
   3.667299466145545*^9, 3.667299904129342*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\[Beta]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, {
  3.667297405416499*^9, 3.667297405686414*^9}, {3.667297476573328*^9, 
  3.6672974768655252`*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.6672974062368383`*^9, {3.667297463588847*^9, 3.667297477496127*^9}, 
   3.6672980103933163`*^9, 3.667298671221871*^9, 3.667298737033689*^9, 
   3.667299027938229*^9, 3.667299192667368*^9, 3.667299256465981*^9, 
   3.667299466163084*^9, 3.667299904156803*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "\"\<\[Beta]\[Beta]\[Beta]\>\"", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.667297480927243*^9, 3.6672974811968813`*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, {3.667297463788726*^9, 
   3.667297481769677*^9}, 3.667298010420331*^9, 3.66729867125*^9, 
   3.667298737063992*^9, 3.667299027967717*^9, 3.667299192708391*^9, 
   3.6672992564990473`*^9, 3.667299466195552*^9, 3.667299904189928*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["1 spin-1", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.6672973784273167`*^9}, 
   3.667297457561099*^9, {3.667298748240841*^9, 3.6672987576450863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{"{", "1", "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}, 
   3.6672973814328327`*^9, 3.667297459922954*^9, {3.66729876068281*^9, 
   3.667298761751178*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\[NoBreak]\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672991966317472`*^9, 3.667299256633667*^9, 
   3.66729947065466*^9, 3.667299921766416*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\
\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672991966317472`*^9, 3.667299256633667*^9, 
   3.66729947065466*^9, 3.667299921894758*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm], "2"]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, {
  3.667299904110488*^9, 3.667299921923319*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, 3.667299196795261*^9, 3.667299256842401*^9, 
   3.667299470825593*^9, 3.667299921958888*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "3", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, {
  3.667297405416499*^9, 3.667297405686414*^9}, {3.667297476573328*^9, 
  3.6672974768655252`*^9}, {3.667298778807467*^9, 3.6672987987095003`*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.6672974062368383`*^9, {3.667297463588847*^9, 3.667297477496127*^9}, 
   3.6672980103933163`*^9, 3.667298671221871*^9, 3.667298737033689*^9, {
   3.667298779626184*^9, 3.667298799034931*^9}, 3.667299196833*^9, 
   3.667299256863998*^9, 3.6672994708420963`*^9, 3.6672999219924507`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.667297480927243*^9, 3.6672974811968813`*^9}, 3.667298804502104*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, {3.667297463788726*^9, 
   3.667297481769677*^9}, 3.667298010420331*^9, 3.66729867125*^9, 
   3.667298737063992*^9, 3.667298805274869*^9, 3.66729919686679*^9, 
   3.6672992569001837`*^9, 3.6672994708718567`*^9, 3.667299922025038*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["spin-1/2, spin-1 system", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.6672973784273167`*^9}, 
   3.667297457561099*^9, {3.667298748240841*^9, 3.6672987576450863`*^9}, {
   3.6672988142680273`*^9, 3.667298824819407*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"1", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}, 
   3.6672973814328327`*^9, 3.667297459922954*^9, {3.66729876068281*^9, 
   3.667298761751178*^9}, {3.667298829477364*^9, 3.667298834359654*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
\\\"1\\\"}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672988350394983`*^9, 3.667299200876053*^9, 
   3.667299257043111*^9, 3.667299474342225*^9, 3.667299945419674*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672988350394983`*^9, 3.667299200876053*^9, 
   3.667299257043111*^9, 3.667299474342225*^9, 3.667299945555573*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm], "3"]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, {
  3.667299904110488*^9, 3.667299945591249*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "]"}]], "Input",
 CellChangeTimes->{3.667299952794718*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm], "3"], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm], "4"]}]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, {
  3.667299904110488*^9, 3.6672999533382673`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BasisKets", "[", "]"}]], "Input",
 CellChangeTimes->{{3.667298837748631*^9, 3.667298840041696*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.667298840462816*^9, 3.6672992010302343`*^9, 
  3.667299257189663*^9, 3.66729947450771*^9, 3.667299945612484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, 3.667298845756051*^9, 3.667299201057811*^9, 
   3.667299257218123*^9, 3.667299474546619*^9, 3.667299945655512*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9, {3.66729885187678*^9, 
   3.667298862542053*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, {3.667298845756051*^9, 3.6672988632389402`*^9}, 
   3.667299201076779*^9, 3.66729925725135*^9, 3.667299474578986*^9, 
   3.667299945689447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.667297480927243*^9, 3.6672974811968813`*^9}, 3.667298804502104*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, {3.667297463788726*^9, 
   3.667297481769677*^9}, 3.667298010420331*^9, 3.66729867125*^9, 
   3.667298737063992*^9, 3.667298805274869*^9, 3.667298870406651*^9, 
   3.66729920110705*^9, 3.6672992572850323`*^9, 3.667299474611961*^9, 
   3.667299945722419*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["spin-1/2, spin-1,spin-3/2 system", "Subchapter",
 CellChangeTimes->{{3.667297362879712*^9, 3.6672973784273167`*^9}, 
   3.667297457561099*^9, {3.667298748240841*^9, 3.6672987576450863`*^9}, {
   3.6672988142680273`*^9, 3.667298824819407*^9}, {3.667299481142866*^9, 
   3.667299483493381*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"1", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"3", "/", "2"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.667297149836404*^9, 3.667297152921826*^9}, 
   3.6672973814328327`*^9, 3.667297459922954*^9, {3.66729876068281*^9, 
   3.667298761751178*^9}, {3.667298829477364*^9, 3.667298834359654*^9}, {
   3.6672994889835873`*^9, 3.667299491976145*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
\\\"1\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \\\
\",\\\", FractionBox[\\\"3\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\
\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672988350394983`*^9, 3.667299200876053*^9, 
   3.667299257043111*^9, {3.667299474342225*^9, 3.667299492766255*^9}, 
   3.667299983942502*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \\\",\\\", FractionBox[\\\"3\\\
\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \
\\\"]\\\"}]\\)\[NoBreak].\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.6672971536086473`*^9, 3.6672973818690767`*^9, 3.667297463046542*^9, 
   3.6672980100718927`*^9, 3.6672986710230703`*^9, {3.667298736850156*^9, 
   3.6672987623862123`*^9}, 3.6672988350394983`*^9, 3.667299200876053*^9, 
   3.667299257043111*^9, {3.667299474342225*^9, 3.667299492766255*^9}, 
   3.66729998406726*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm], "12"]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, {
   3.667299904110488*^9, 3.667299945591249*^9}, 3.66729998411366*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationOperator", "[", "]"}]], "Input",
 CellChangeTimes->{3.667299952794718*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm], "12"], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm], "16"], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"3", "z"}]],
    DisplayForm], "20"]}]], "Output",
 CellChangeTimes->{{3.6672998373610573`*^9, 3.667299863624434*^9}, {
   3.667299904110488*^9, 3.6672999533382673`*^9}, 3.6672999841339407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BasisKets", "[", "]"}]], "Input",
 CellChangeTimes->{{3.667298837748631*^9, 3.667298840041696*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"+", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox["0",
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["1", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], ",", 
     TagBox["1",
      DisplayForm], 
     TagBox[
      RowBox[{"-", "1"}],
      DisplayForm], ",", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.667298840462816*^9, 3.6672992010302343`*^9, 3.667299257189663*^9, {
   3.66729947450771*^9, 3.66729949590786*^9}, 3.667299984167223*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "1", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, 3.667298845756051*^9, 3.667299201057811*^9, 
   3.667299257218123*^9, {3.667299474546619*^9, 3.6672995026522093`*^9}, 
   3.6672999842126083`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9, {3.66729885187678*^9, 
   3.667298862542053*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, {3.667298845756051*^9, 3.6672988632389402`*^9}, 
   3.667299201076779*^9, 3.66729925725135*^9, {3.667299474578986*^9, 
   3.667299502686241*^9}, 3.66729998424578*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297226903434*^9}, {
   3.667297385368788*^9, 3.66729738572875*^9}, {3.667297471657997*^9, 
   3.6672974719718246`*^9}, 3.667298771280719*^9, {3.66729885187678*^9, 
   3.667298862542053*^9}, 3.667299508762282*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297227830041*^9}, 
   3.667297386855274*^9, {3.667297463394899*^9, 3.667297472700982*^9}, 
   3.667298010375115*^9, 3.6672986712024317`*^9, {3.667298737016548*^9, 
   3.667298771581729*^9}, {3.667298845756051*^9, 3.6672988632389402`*^9}, 
   3.667299201076779*^9, 3.66729925725135*^9, {3.667299474578986*^9, 
   3.667299509080153*^9}, 3.6672999842802353`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{
   RowBox[{"PopulationOperator", "[", 
    RowBox[{"Ket", "[", "1", "]"}], "]"}], "->", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.667297194963901*^9, 3.667297236530817*^9}, 
   3.667297356153303*^9, {3.667297410636476*^9, 3.667297410861185*^9}, {
   3.667297480927243*^9, 3.6672974811968813`*^9}, 3.667298804502104*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.667297220928075*^9, 3.667297237075965*^9}, 
   3.667297356757325*^9, 3.6672974114125147`*^9, {3.667297463788726*^9, 
   3.667297481769677*^9}, 3.667298010420331*^9, 3.66729867125*^9, 
   3.667298737063992*^9, 3.667298805274869*^9, 3.667298870406651*^9, 
   3.66729920110705*^9, 3.6672992572850323`*^9, {3.667299474611961*^9, 
   3.667299502711547*^9}, 3.6672999843130083`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["thermal polarization level", "Chapter",
 CellChangeTimes->{{3.667296655402238*^9, 3.667296655897064*^9}, {
   3.6672971480056057`*^9, 3.667297148544764*^9}, {3.667299615255541*^9, 
   3.667299624727354*^9}, 3.66729971174894*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.6672996300378933`*^9, 3.6672996337280684`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.66729963450634*^9, 3.667300004606393*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \
\\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.66729963450634*^9, 3.6673000047320833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]eq", "=", 
  RowBox[{"ThermalEquilibriumDensityOperator", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "\[Pi]", " ", "500", " ", 
     RowBox[{"10", "^", "6"}], " ", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "300"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.667299637655652*^9, 3.667299696808069*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"Operator[<<..>>, OperatorType\[Rule]\"\>", \
"\<\"\\\"Hermitian\\\"\"\>", "\<\"]\"\>"}],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6672996675549707`*^9, 3.667299697450204*^9}, 
   3.667300004770932*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"OperatorAmplitude", "[", 
  RowBox[{"\[Rho]eq", "\[Rule]", 
   RowBox[{"PolarizationOperator", "[", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "EngineeringForm"}]}], "Input",
 CellChangeTimes->{{3.667299670361073*^9, 3.6672996909844217`*^9}}],

Cell[BoxData["0.00003999369459591640398414129215222507`5.227880779141553"], \
"Output",
 CellChangeTimes->{{3.66729968282232*^9, 3.6672997010774317`*^9}, 
   3.667300004786653*^9}],

Cell[BoxData[
 TagBox[
  InterpretationBox[
   RowBox[{"\<\"39.994\"\>", "\[Times]", 
    SuperscriptBox["10", "\<\"-6\"\>"]}],
   0.00003999369459591640398414129215222507`5.227880779141553,
   AutoDelete->True],
  EngineeringForm]], "Output",
 CellChangeTimes->{{3.66729968282232*^9, 3.6672997010774317`*^9}, 
   3.667300004790333*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 901},
WindowMargins->{{273, Automatic}, {30, Automatic}},
FrontEndVersion->"10.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 10, \
2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 89, 1, 65, "Chapter"],
Cell[672, 25, 146, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[843, 31, 134, 2, 62, "Subchapter"],
Cell[980, 35, 820, 14, 148, "Input"],
Cell[1803, 51, 753, 20, 46, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[2559, 73, 227, 5, 28, "Input"],
Cell[2789, 80, 304, 7, 28, "Input"],
Cell[3096, 89, 386, 10, 28, "Input"],
Cell[3485, 101, 802, 22, 63, "Input"],
Cell[4290, 125, 574, 17, 63, "Input"],
Cell[4867, 144, 1689, 41, 148, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6605, 191, 141, 2, 65, "Chapter"],
Cell[CellGroupData[{
Cell[6771, 197, 103, 1, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[6899, 202, 132, 2, 28, "Input"],
Cell[7034, 206, 688, 14, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7759, 225, 73, 1, 28, "Input"],
Cell[7835, 228, 161, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8033, 238, 301, 6, 28, "Input"],
Cell[8337, 246, 355, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8729, 256, 300, 6, 28, "Input"],
Cell[9032, 264, 370, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9439, 275, 321, 7, 28, "Input"],
Cell[9763, 284, 401, 6, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10213, 296, 103, 1, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[10341, 301, 160, 3, 28, "Input"],
Cell[10504, 306, 797, 15, 40, "Message"],
Cell[11304, 323, 938, 17, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12279, 345, 73, 1, 28, "Input"],
Cell[12355, 348, 186, 6, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12578, 359, 110, 2, 28, "Input"],
Cell[12691, 363, 308, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13036, 380, 357, 7, 28, "Input"],
Cell[13396, 389, 350, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13783, 399, 356, 7, 28, "Input"],
Cell[14142, 408, 376, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14555, 419, 381, 7, 28, "Input"],
Cell[14939, 428, 403, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15379, 439, 374, 7, 28, "Input"],
Cell[15756, 448, 398, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16191, 459, 427, 8, 28, "Input"],
Cell[16621, 469, 413, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17071, 480, 456, 8, 28, "Input"],
Cell[17530, 490, 368, 8, 21, "Message"],
Cell[17901, 500, 633, 11, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[18583, 517, 127, 2, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[18735, 523, 182, 3, 28, "Input"],
Cell[18920, 528, 872, 15, 40, "Message"],
Cell[19795, 545, 1013, 17, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20845, 567, 73, 1, 28, "Input"],
Cell[20921, 570, 212, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21170, 582, 416, 8, 28, "Input"],
Cell[21589, 592, 360, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21986, 602, 414, 8, 28, "Input"],
Cell[22403, 612, 375, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22815, 623, 433, 8, 28, "Input"],
Cell[23251, 633, 393, 6, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23693, 645, 172, 2, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[23890, 651, 278, 6, 28, "Input"],
Cell[24171, 659, 618, 13, 21, "Message"],
Cell[24792, 674, 759, 15, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25588, 694, 73, 1, 28, "Input"],
Cell[25664, 697, 235, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25936, 709, 409, 8, 28, "Input"],
Cell[26348, 719, 358, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26743, 729, 434, 8, 28, "Input"],
Cell[27180, 739, 400, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27617, 750, 427, 8, 28, "Input"],
Cell[28047, 760, 377, 5, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[28473, 771, 239, 3, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[28737, 778, 453, 11, 28, "Input"],
Cell[29193, 791, 763, 14, 40, "Message"],
Cell[29959, 807, 904, 16, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30900, 828, 73, 1, 28, "Input"],
Cell[30976, 831, 235, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31248, 843, 110, 2, 28, "Input"],
Cell[31361, 847, 359, 13, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31757, 865, 123, 2, 28, "Input"],
Cell[31883, 869, 2237, 92, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34157, 966, 409, 8, 28, "Input"],
Cell[34569, 976, 380, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34986, 986, 458, 9, 28, "Input"],
Cell[35447, 997, 409, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35893, 1008, 427, 8, 28, "Input"],
Cell[36323, 1018, 401, 6, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36773, 1030, 298, 4, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[37096, 1038, 593, 15, 28, "Input"],
Cell[37692, 1055, 905, 17, 40, "Message"],
Cell[38600, 1074, 1045, 19, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39682, 1098, 73, 1, 28, "Input"],
Cell[39758, 1101, 258, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40053, 1113, 110, 2, 28, "Input"],
Cell[40166, 1117, 492, 18, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40695, 1140, 123, 2, 28, "Input"],
Cell[40821, 1144, 12110, 525, 238, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[52968, 1674, 409, 8, 22, "Input"],
Cell[53380, 1684, 412, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53829, 1695, 458, 9, 28, "Input"],
Cell[54290, 1706, 432, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54759, 1717, 480, 9, 28, "Input"],
Cell[55242, 1728, 435, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55714, 1739, 427, 8, 28, "Input"],
Cell[56144, 1749, 427, 6, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[56632, 1762, 234, 3, 54, "Chapter"],
Cell[CellGroupData[{
Cell[56891, 1769, 136, 2, 28, "Input"],
Cell[57030, 1773, 539, 11, 40, "Message"],
Cell[57572, 1786, 682, 13, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58291, 1804, 355, 9, 28, "Input"],
Cell[58649, 1815, 247, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58933, 1826, 284, 5, 46, "Input"],
Cell[59220, 1833, 180, 3, 28, "Output"],
Cell[59403, 1838, 336, 9, 43, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
